Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(441)

Unified Diff: content/browser/frame_host/frame_mojo_shell.h

Issue 1679573002: Move shell interfaces into the shell.mojom namespace. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@delegate
Patch Set: . Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/web_view/frame_utils.cc ('k') | content/browser/frame_host/frame_mojo_shell.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/frame_host/frame_mojo_shell.h
diff --git a/content/browser/frame_host/frame_mojo_shell.h b/content/browser/frame_host/frame_mojo_shell.h
index 08a60e9b8310a250f6a0aa1192c8f45047e88df0..1f1030f0f1e403364e4a8532e7901c14a2ecbc25 100644
--- a/content/browser/frame_host/frame_mojo_shell.h
+++ b/content/browser/frame_host/frame_mojo_shell.h
@@ -16,14 +16,16 @@ namespace content {
class RenderFrameHost;
class ServiceRegistryImpl;
-// This provides the |mojo::Shell| service interface to each frame's
-// ServiceRegistry, giving frames the ability to connect to Mojo applications.
-class FrameMojoShell : public mojo::Shell {
+// This provides the |mojo::shell::mojom::Shell| service interface to each
+// frame's ServiceRegistry, giving frames the ability to connect to Mojo
+// applications.
+class FrameMojoShell : public mojo::shell::mojom::Shell {
public:
explicit FrameMojoShell(RenderFrameHost* frame_host);
~FrameMojoShell() override;
- void BindRequest(mojo::InterfaceRequest<mojo::Shell> shell_request);
+ void BindRequest(
+ mojo::InterfaceRequest<mojo::shell::mojom::Shell> shell_request);
private:
// mojo::Shell:
@@ -31,14 +33,14 @@ class FrameMojoShell : public mojo::Shell {
mojo::URLRequestPtr application_url,
mojo::InterfaceRequest<mojo::ServiceProvider> services,
mojo::ServiceProviderPtr exposed_services,
- mojo::CapabilityFilterPtr filter,
+ mojo::shell::mojom::CapabilityFilterPtr filter,
const ConnectToApplicationCallback& callback) override;
void QuitApplication() override;
ServiceRegistryImpl* GetServiceRegistry();
RenderFrameHost* frame_host_;
- mojo::WeakBindingSet<mojo::Shell> bindings_;
+ mojo::WeakBindingSet<mojo::shell::mojom::Shell> bindings_;
// ServiceRegistry providing browser services to connected applications.
scoped_ptr<ServiceRegistryImpl> service_registry_;
« no previous file with comments | « components/web_view/frame_utils.cc ('k') | content/browser/frame_host/frame_mojo_shell.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698